==> spip_4.2.12+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_ja.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=ja
// ** ne pas modifier le fichier **

return [

	// A
	'aucun_message_forum' => '掲示板メッセージがありません',

	// B
	'bouton_radio_articles_futurs' => '今から作成される記事のみ（データベースにある記事はそのまま）',
	'bouton_radio_articles_tous' => '例外なく、すべての記事に。',
	'bouton_radio_articles_tous_sauf_forum_desactive' => '不許可になった記事を除いて、掲示板機能はすべての記事に許可されます。',
	'bouton_radio_enregistrement_obligatoire' => '登録が必要です。（コメントを投稿する前に、ユーザーはＥメールアドレスを記入して登録する必要があります。）',
	'bouton_radio_moderation_priori' => '事前調整（投稿は管理者による検証の上で表示されます）',
	'bouton_radio_modere_abonnement' => '登録が必要',
	'bouton_radio_modere_posteriori' => '事後調整',
	'bouton_radio_modere_priori' => '事前調整',
	'bouton_radio_publication_immediate' => '調整なしでコメントをすぐ投稿する',

	// D
	'documents_interdits_forum' => 'この掲示板で禁止されたドキュメント',

	// E
	'erreur_enregistrement_message' => '技術的な問題が起こって、メッセージを保存出来ませんでした。',
	'extensions_autorisees' => '承認された拡張機能：',
	'extensions_autorisees_toutes' => '全',

	// F
	'form_pet_message_commentaire' => 'よろしければ、メッセージをお寄せください。',
	'forum' => '掲示板',
	'forum_acces_refuse' => 'これらの掲示板にアクセス出来なくなりました。',
	'forum_attention_dix_caracteres' => '<b>警告！</b>投稿は10文字以上でなければなりません。',
	'forum_attention_message_non_poste' => '<b>警告！</b>メッセージを投稿しませんでした！',
	'forum_attention_nb_caracteres_mini' => '<b>警告！</b>投稿は@min@文字以上でなければなりません。',
	'forum_attention_trois_caracteres' => '<b>警告！</b>題名は3文字以上でなければなりません。',
	'forum_attention_trop_caracteres' => '<b>警告！</b>メッセージは長すぎて（@compte@文字）、保存出来ません。1000文字を超えることは出来ません。',
	'forum_avez_selectionne' => '選択されたのは：',
	'forum_cliquer_retour' => '<a href=\\"@retour_forum@\\">ここ</a> を押して続けて下さい。',
	'forum_envoyer' => '投稿する',
	'forum_forum' => '掲示板',
	'forum_info_modere' => 'この掲示板への投稿はあらかじめ点検されます。あなたの投稿は、サイトの管理者によって適性検査の上で表示されます。',
	'forum_lien_hyper' => 'ハイパーテキストリンク（オプション）',
	'forum_message' => 'あなたのメッセージ：',
	'forum_message_definitif' => '確認された投稿をサイトへ送る',
	'forum_message_trop_long' => 'このメッセージは長すぎます。最大20000文字（全角は10000文字）であるべきです。',
	'forum_ne_repondez_pas' => 'このメールに返信しないでください。返事は、掲示板で：',
	'forum_page_url' => '（あなたのメッセージは、ウェブに公表されている記事、更なる情報が提供されているページを参照するなら、下にページのタイトルとそのURLを入力してください。）',
	'forum_permalink' => 'コメントへの永久的なリンク',
	'forum_poste_par' => '記事「@titre@」のゆえに、 @parauteur@によって投稿されたコメント。',
	'forum_poste_par_court' => '@parauteur@によって投稿されたコメント。',
	'forum_poste_par_generique' => '（@objet@「@titre@」）@parauteur@によって投稿されたコメント',
	'forum_qui_etes_vous' => 'あなたは誰ですか。',
	'forum_saisie_texte_info' => 'このフォームは、SPIPショートカット（<code>[-&gt;url] {{gras}} {italique} &lt;quote&gt; &lt;code&gt;</code>）とHTMLタグ（<code>&lt;q&gt; &lt;del&gt; &lt;ins&gt;</code>）を受け入れます。段落を作成するには、空の行を残してください。',
	'forum_texte' => 'あなたの文書：',
	'forum_titre' => '件名',
	'forum_url' => '個人サイトのURL（オプション）',
	'forum_valider' => '選択を確認',
	'forum_voir_avant' => '投稿する前にメッセージをプレビュー',
	'forum_votre_email' => 'あなたのＥメールアドレス',
	'forum_votre_nom' => 'お名前',
	'forum_vous_enregistrer' => 'このフォーラムに参加する前にログインする必要があります。個人的なＩＤを入力してください。',
	'forum_vous_inscrire' => 'まだ登録していない場合は、登録する必要があります。',

	// I
	'icone_bruler_message' => '迷惑物として報告する',
	'icone_bruler_messages' => '迷惑メールとして報告する',
	'icone_legitimer_message' => '合法メールとして報告する',
	'icone_poster_message' => 'メッセージの投稿する',
	'icone_suivi_forum' => '公開掲示板：投稿@nb_forums@件',
	'icone_suivi_forums' => '掲示板を管理する',
	'icone_supprimer_message' => 'このメッセージを削除',
	'icone_supprimer_messages' => 'これらのメッセージを削除',
	'icone_valider_message' => 'このメッセージを有効',
	'icone_valider_messages' => 'これらのメッセージを有効',
	'icone_valider_repondre_message' => 'このメッセージを有効して返事する',
	'info_1_message_forum' => 'メッセージ１件',
	'info_activer_forum_public' => '公開フォーラムを有効にするには、標準の操作方法を選択してください：',
	'info_appliquer_choix_moderation' => 'この統制方法を使う:',
	'info_config_forums_prive' => '管理エリアには、様々な種類の掲示板を作動させることが出来ます：',
	'info_config_forums_prive_admin' => '管理者用に予約された掲示板：',
	'info_config_forums_prive_global' => 'すべての著者に開放されたグローバル掲示板：',
	'info_config_forums_prive_objets' => '各記事、ニュース、参照されたサイトなどに付いた掲示板：',
	'info_desactiver_forum_public' => '公開掲示板の使用を無効にする。公開掲示板は、記事ごとにケースバイケースで有効にすることが出来ます。セクション、ニュースなどのために永久に無効になります。',
	'info_envoi_forum' => '記事に添付された掲示板のメッセージを著者に送信する',
	'info_fonctionnement_forum' => '掲示板の操作：',
	'info_forcer_previsualisation_court' => 'プレビューを強制する',
	'info_forcer_previsualisation_long' => 'メッセージを送信する前にプレビューを強制する',
	'info_forums_liees_mot' => 'この単語に関連する掲示板のメッセージ',
	'info_gauche_suivi_forum_2' => '掲示板管理ページは、サイト管理ツールであり、会話や編集エリアではありません。公開サイトと管理エリアの両方のフォーラムへの寄稿をすべて表示し、これらの寄与を管理することが出来ます。',
	'info_liens_syndiques_3' => '掲示板は、',
	'info_liens_syndiques_4' => '　',
	'info_liens_syndiques_5' => '掲示板',
	'info_liens_syndiques_6' => '　',
	'info_liens_syndiques_7' => '検証のために処理されています。',
	'info_liens_texte' => 'メッセージテキスト内に含まれたリンク',
	'info_liens_titre' => 'メッセージ件名内に含まれたリンク',
	'info_mode_fonctionnement_defaut_forum_public' => '公開掲示板の標準の操作方法',
	'info_nb_messages_forum' => 'メッセージ@nb@件',
	'info_option_email' => '訪問者が記事の掲示板にメッセージを投稿するとき、その記事の著者にＥメールで通知することが出来ます。掲示板の種類ごとに、このオプションを有効にするかどうかを指定します。',
	'info_pas_de_forum' => '掲示板無し',
	'info_question_visiteur_ajout_document_forum' => '訪問者がドキュメント（画像、サウンドファイルなど）を掲示板の投稿に添付できるようにするには、受け入れられるファイル拡張子を指示してください。（例：gif、jpg、png、mp3）。',
	'info_question_visiteur_ajout_document_forum_format' => 'SPIPによって安全とみなされるすべての文書タイプを承認する場合は、アスタリスク（*）を使用してください。何も認可しないように、空にそのまま残してください。',
	'info_selectionner_message' => 'メッセージを選択してください：',
	'interface_formulaire' => 'フォームインタフェース',
	'interface_onglets' => 'タブ付きインタフェース',
	'item_activer_forum_administrateur' => '管理者用の掲示板を有効にする',
	'item_config_forums_prive_global' => '著者用の掲示板を有効にする',
	'item_config_forums_prive_objets' => 'これらの掲示板を有効にする',
	'item_desactiver_forum_administrateur' => '管理者用の掲示板を無効にする',
	'item_non_config_forums_prive_global' => '著者用の掲示板を無効にする',
	'item_non_config_forums_prive_objets' => 'これらの掲示板を無効にする',

	// L
	'label_selectionner' => '選択：',
	'lien_reponse_article' => '記事に返信',
	'lien_reponse_breve_2' => 'ニュースに返信',
	'lien_reponse_message' => 'メッセージに返信',
	'lien_reponse_rubrique' => 'セクションに返信',
	'lien_reponse_site_reference' => '参照されたサイトに返信',
	'lien_vider_selection' => '選択を空にする',

	// M
	'messages_aucun' => '無し',
	'messages_meme_auteur' => 'この著者のすべてのメッセージ',
	'messages_meme_email' => 'このＥメールのすべてのメッセージ',
	'messages_meme_ip' => 'このＩＰのすべてのメッセージ',
	'messages_off' => '削除',
	'messages_perso' => '個人',
	'messages_privadm' => '管理者',
	'messages_prive' => 'プライベート',
	'messages_privoff' => '削除',
	'messages_privrac' => '一般',
	'messages_prop' => '提出',
	'messages_publie' => '公開',
	'messages_spam' => '迷惑',
	'messages_tous' => '全て',

	// O
	'onglet_messages_internes' => '内部のメッセージ',
	'onglet_messages_publics' => '公開されたメッセージ',
	'onglet_messages_vide' => 'テキストがないメッセージ',

	// R
	'repondre_message' => 'このメッセージに返信',

	// S
	'statut_off' => '削除',
	'statut_original' => '原文',
	'statut_prop' => '提出',
	'statut_publie' => '公開',
	'statut_spam' => '迷惑物',

	// T
	'text_article_propose_publication_forum' => 'この記事は、下記の掲示板でコメントすることが出来ます。',
	'texte_en_cours_validation' => '公開のために、以下の記事、ニュース、メッセージなどは提出されます。',
	'texte_en_cours_validation_forum' => 'これらのものは、下記の掲示板でコメントすることが出来ます。',
	'texte_messages_publics' => '公開メッセージ：',
	'titre_cadre_forum_administrateur' => '管理者用のプライベートな掲示板',
	'titre_cadre_forum_interne' => '関係者用の掲示板',
	'titre_config_forums_prive' => '管理エリアの掲示板',
	'titre_forum' => '掲示板',
	'titre_forum_suivi' => '掲示板を管理',
	'titre_page_forum_suivi' => '掲示板の続報',
	'titre_selection_action' => '選択',
	'tout_voir' => 'すべてのメッセージを表示',

	// V
	'voir_messages_objet' => 'メッセージを表示',
];

==> spip_4.4.3+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_ja.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=ja
// ** ne pas modifier le fichier **

return [

	// A
	'aucun_message_forum' => '掲示板メッセージがありません',

	// B
	'bouton_radio_articles_futurs' => '今から作成される記事のみ（データベースにある記事はそのまま）',
	'bouton_radio_articles_tous' => '例外なく、すべての記事に。',
	'bouton_radio_articles_tous_sauf_forum_desactive' => '不許可になった記事を除いて、掲示板機能はすべての記事に許可されます。',
	'bouton_radio_enregistrement_obligatoire' => '登録が必要です。（コメントを投稿する前に、ユーザーはＥメールアドレスを記入して登録する必要があります。）', # MODIF
	'bouton_radio_moderation_priori' => '事前調整（投稿は管理者による検証の上で表示されます）', # MODIF
	'bouton_radio_modere_abonnement' => '登録が必要',
	'bouton_radio_modere_posteriori' => '事後調整',
	'bouton_radio_modere_priori' => '事前調整',
	'bouton_radio_publication_immediate' => '調整なしでコメントをすぐ投稿する', # MODIF

	// D
	'documents_interdits_forum' => 'この掲示板で禁止されたドキュメント',

	// E
	'erreur_enregistrement_message' => '技術的な問題が起こって、メッセージを保存出来ませんでした。',
	'extensions_autorisees' => '承認された拡張機能：',
	'extensions_autorisees_toutes' => '全',

	// F
	'form_pet_message_commentaire' => 'よろしければ、メッセージをお寄せください。',
	'forum' => '掲示板',
	'forum_acces_refuse' => 'これらの掲示板にアクセス出来なくなりました。',
	'forum_attention_dix_caracteres' => '<b>警告！</b>投稿は10文字以上でなければなりません。',
	'forum_attention_message_non_poste' => '<b>警告！</b>メッセージを投稿しませんでした！',
	'forum_attention_nb_caracteres_mini' => '<b>警告！</b>投稿は@min@文字以上でなければなりません。',
	'forum_attention_trois_caracteres' => '<b>警告！</b>題名は3文字以上でなければなりません。',
	'forum_attention_trop_caracteres' => '<b>警告！</b>メッセージは長すぎて（@compte@文字）、保存出来ません。1000文字を超えることは出来ません。',
	'forum_avez_selectionne' => '選択されたのは：',
	'forum_cliquer_retour' => '<a href=\\"@retour_forum@\\">ここ</a> を押して続けて下さい。',
	'forum_envoyer' => '投稿する',
	'forum_forum' => '掲示板',
	'forum_info_modere' => 'この掲示板への投稿はあらかじめ点検されます。あなたの投稿は、サイトの管理者によって適性検査の上で表示されます。', # MODIF
	'forum_lien_hyper' => 'ハイパーテキストリンク（オプション）',
	'forum_message' => 'あなたのメッセージ：',
	'forum_message_definitif' => '確認された投稿をサイトへ送る',
	'forum_message_trop_long' => 'このメッセージは長すぎます。最大20000文字（全角は10000文字）であるべきです。',
	'forum_ne_repondez_pas' => 'このメールに返信しないでください。返事は、掲示板で：',
	'forum_page_url' => '（あなたのメッセージは、ウェブに公表されている記事、更なる情報が提供されているページを参照するなら、下にページのタイトルとそのURLを入力してください。）',
	'forum_permalink' => 'コメントへの永久的なリンク',
	'forum_poste_par' => '記事「@titre@」のゆえに、 @parauteur@によって投稿されたコメント。',
	'forum_poste_par_court' => '@parauteur@によって投稿されたコメント。',
	'forum_poste_par_generique' => '（@objet@「@titre@」）@parauteur@によって投稿されたコメント',
	'forum_qui_etes_vous' => 'あなたは誰ですか。',
	'forum_saisie_texte_info' => 'このフォームは、SPIPショートカット（<code>[-&gt;url] {{gras}} {italique} &lt;quote&gt; &lt;code&gt;</code>）とHTMLタグ（<code>&lt;q&gt; &lt;del&gt; &lt;ins&gt;</code>）を受け入れます。段落を作成するには、空の行を残してください。',
	'forum_texte' => 'あなたの文書：',
	'forum_titre' => '件名',
	'forum_url' => '個人サイトのURL（オプション）',
	'forum_valider' => '選択を確認',
	'forum_voir_avant' => '投稿する前にメッセージをプレビュー',
	'forum_votre_email' => 'あなたのＥメールアドレス',
	'forum_votre_nom' => 'お名前',
	'forum_vous_enregistrer' => 'このフォーラムに参加する前にログインする必要があります。個人的なＩＤを入力してください。',
	'forum_vous_inscrire' => 'まだ登録していない場合は、登録する必要があります。',

	// I
	'icone_bruler_message' => '迷惑物として報告する',
	'icone_bruler_messages' => '迷惑メールとして報告する',
	'icone_legitimer_message' => '合法メールとして報告する',
	'icone_poster_message' => 'メッセージの投稿する',
	'icone_suivi_forum' => '公開掲示板：投稿@nb_forums@件',
	'icone_suivi_forums' => '掲示板を管理する',
	'icone_supprimer_message' => 'このメッセージを削除',
	'icone_supprimer_messages' => 'これらのメッセージを削除',
	'icone_valider_message' => 'このメッセージを有効',
	'icone_valider_messages' => 'これらのメッセージを有効',
	'icone_valider_repondre_message' => 'このメッセージを有効して返事する',
	'info_1_message_forum' => 'メッセージ１件',
	'info_activer_forum_public' => '公開フォーラムを有効にするには、標準の操作方法を選択してください：',
	'info_appliquer_choix_moderation' => 'この統制方法を使う:',
	'info_config_forums_prive' => '管理エリアには、様々な種類の掲示板を作動させることが出来ます：',
	'info_config_forums_prive_admin' => '管理者用に予約された掲示板：', # MODIF
	'info_config_forums_prive_global' => 'すべての著者に開放されたグローバル掲示板：', # MODIF
	'info_config_forums_prive_objets' => '各記事、ニュース、参照されたサイトなどに付いた掲示板：',
	'info_desactiver_forum_public' => '公開掲示板の使用を無効にする。公開掲示板は、記事ごとにケースバイケースで有効にすることが出来ます。セクション、ニュースなどのために永久に無効になります。',
	'info_envoi_forum' => '記事に添付された掲示板のメッセージを著者に送信する', # MODIF
	'info_fonctionnement_forum' => '掲示板の操作：',
	'info_forcer_previsualisation_court' => 'プレビューを強制する',
	'info_forcer_previsualisation_long' => 'メッセージを送信する前にプレビューを強制する',
	'info_forums_liees_mot' => 'この単語に関連する掲示板のメッセージ',
	'info_gauche_suivi_forum_2' => '掲示板管理ページは、サイト管理ツールであり、会話や編集エリアではありません。公開サイトと管理エリアの両方のフォーラムへの寄稿をすべて表示し、これらの寄与を管理することが出来ます。',
	'info_liens_syndiques_3' => '掲示板は、',
	'info_liens_syndiques_4' => '　',
	'info_liens_syndiques_5' => '掲示板',
	'info_liens_syndiques_6' => '　',
	'info_liens_syndiques_7' => '検証のために処理されています。',
	'info_liens_texte' => 'メッセージテキスト内に含まれたリンク',
	'info_liens_titre' => 'メッセージ件名内に含まれたリンク',
	'info_mode_fonctionnement_defaut_forum_public' => '公開掲示板の標準の操作方法',
	'info_nb_messages_forum' => 'メッセージ@nb@件',
	'info_option_email' => '訪問者が記事の掲示板にメッセージを投稿するとき、その記事の著者にＥメールで通知することが出来ます。掲示板の種類ごとに、このオプションを有効にするかどうかを指定します。', # MODIF
	'info_pas_de_forum' => '掲示板無し',
	'info_question_visiteur_ajout_document_forum' => '訪問者がドキュメント（画像、サウンドファイルなど）を掲示板の投稿に添付できるようにするには、受け入れられるファイル拡張子を指示してください。（例：gif、jpg、png、mp3）。', # MODIF
	'info_question_visiteur_ajout_document_forum_format' => 'SPIPによって安全とみなされるすべての文書タイプを承認する場合は、アスタリスク（*）を使用してください。何も認可しないように、空にそのまま残してください。',
	'info_selectionner_message' => 'メッセージを選択してください：',
	'interface_formulaire' => 'フォームインタフェース',
	'interface_onglets' => 'タブ付きインタフェース',
	'item_activer_forum_administrateur' => '管理者用の掲示板を有効にする', # MODIF
	'item_config_forums_prive_global' => '著者用の掲示板を有効にする', # MODIF
	'item_config_forums_prive_objets' => 'これらの掲示板を有効にする',
	'item_desactiver_forum_administrateur' => '管理者用の掲示板を無効にする', # MODIF
	'item_non_config_forums_prive_global' => '著者用の掲示板を無効にする', # MODIF
	'item_non_config_forums_prive_objets' => 'これらの掲示板を無効にする',

	// L
	'label_selectionner' => '選択：',
	'lien_reponse_article' => '記事に返信',
	'lien_reponse_breve_2' => 'ニュースに返信',
	'lien_reponse_message' => 'メッセージに返信',
	'lien_reponse_rubrique' => 'セクションに返信',
	'lien_reponse_site_reference' => '参照されたサイトに返信',
	'lien_vider_selection' => '選択を空にする',

	// M
	'messages_aucun' => '無し',
	'messages_meme_auteur' => 'この著者のすべてのメッセージ', # MODIF
	'messages_meme_email' => 'このＥメールのすべてのメッセージ',
	'messages_meme_ip' => 'このＩＰのすべてのメッセージ',
	'messages_off' => '削除',
	'messages_perso' => '個人',
	'messages_privadm' => '管理者', # MODIF
	'messages_prive' => 'プライベート',
	'messages_privoff' => '削除',
	'messages_privrac' => '一般',
	'messages_prop' => '提出',
	'messages_publie' => '公開',
	'messages_spam' => '迷惑',
	'messages_tous' => '全て',

	// O
	'onglet_messages_internes' => '内部のメッセージ',
	'onglet_messages_publics' => '公開されたメッセージ',
	'onglet_messages_vide' => 'テキストがないメッセージ',

	// R
	'repondre_message' => 'このメッセージに返信',

	// S
	'statut_off' => '削除',
	'statut_original' => '原文',
	'statut_prop' => '提出',
	'statut_publie' => '公開',
	'statut_spam' => '迷惑物',

	// T
	'text_article_propose_publication_forum' => 'この記事は、下記の掲示板でコメントすることが出来ます。',
	'texte_en_cours_validation' => '公開のために、以下の記事、ニュース、メッセージなどは提出されます。',
	'texte_en_cours_validation_forum' => 'これらのものは、下記の掲示板でコメントすることが出来ます。',
	'texte_messages_publics' => '公開メッセージ：',
	'titre_cadre_forum_administrateur' => '管理者用のプライベートな掲示板', # MODIF
	'titre_cadre_forum_interne' => '関係者用の掲示板',
	'titre_config_forums_prive' => '管理エリアの掲示板',
	'titre_forum' => '掲示板',
	'titre_forum_suivi' => '掲示板を管理',
	'titre_page_forum_suivi' => '掲示板の続報',
	'titre_selection_action' => '選択',
	'tout_voir' => 'すべてのメッセージを表示',

	// V
	'voir_messages_objet' => 'メッセージを表示',
];
